@@ -32,14 +32,20 @@ sudo zypper --root "${INSTALLROOT}" \
 sudo setarch i686 zypper --root "${INSTALLROOT}"  \
   install --download-only -y \
   bash \
+  docbook-utils \
   filesystem \
+  gawk \
   glibc \
   glibc-extra \
+  grep \
+  gzip \
   libpcre1 \
   libselinux1 \
   openSUSE-release \
   system-user-root \
   util-linux vim \
+  xz \
+  zlib \
   zypper
 sudo rpm -Uvh --root "${INSTALLROOT}" "${INSTALLROOT}/var/cache/zypp/packages/oss/"*"/"*".rpm"
 
