@@ -47,11 +47,12 @@ sudo chroot "${INSTALLROOT}" apt-get -y upgrade
 sudo umount "${INSTALLROOT}/dev/shm"
 sudo umount "${INSTALLROOT}/dev"
 
-sudo tar -C "${INSTALLROOT}" -c . >"${IMAGE}.tar"
+docker rmi -f "${IMAGE}" || :
+sudo tar -C "${INSTALLROOT}" -c . | docker import - "${IMAGE}"
+docker run -ti --rm "${IMAGE}" ls -l
 sudo rm -rf "${INSTALLROOT}"
 
-docker rmi -f "${IMAGE}" || :
-cat "${IMAGE}.tar" | docker import - "${IMAGE}"
+docker image save "${IMAGE}" >"${IMAGE}.tar"
 rm -f "${IMAGE}.tar.gz"
 pigz -9 "${IMAGE}.tar"
 mv -vf "${IMAGE}.tar.gz" "${HOME}/tde/obs"
